import { JSONArray } from '../adapters';
import type { CallerBroker } from '../brokers';
import { CompareHelper, Expression, LogicFlowHelper, MathHelper, StackExpression, StackValue, ValueCheckHelper, VariableHelper } from './agent';
declare class CallerAgentScope {
    readonly id: number;
    readonly syntaxTree: Expression[];
    /**
     * Create a new Scope
     * @param id Scope ID
     */
    constructor(id: number);
    /**
     * Add the expression to the syntax tree in this scope
     * @param exp Expression partial
     * @returns StackRef object
     */
    addExpression<T extends Expression>(exp: T): StackRef;
    /**
     * Get normalized syntax tree
     * @returns Normalized syntax tree
     * @description This will call `toJSON` on each intermediate object
     */
    printTree(): JSONArray;
}
interface StackRef {
    /**
     * Scope index the value
     */
    scopeId: number;
    /**
     * Stack index of the value
     */
    stackId: number;
}
interface CallerAgentProxyHandlerOptions extends CallerAgentProxyHandlerOverridableOptions {
    scopeId: number;
    stackId: number;
}
interface CallerAgentProxyHandlerOverridableOptions {
    isResolved?: boolean;
}
declare class CallerAgentProxyHandler implements ProxyHandler<any> {
    protected readonly scopeRef: RefObject<CallerAgentScope>;
    protected readonly scopeId: number;
    protected readonly stackId: number;
    protected readonly isResolved?: boolean;
    constructor(scopeRef: RefObject<CallerAgentScope>, options: CallerAgentProxyHandlerOptions);
    protected addExpression<T extends StackExpression>(exp: Omit<T, Exclude<keyof StackExpression, keyof Expression>>, options?: CallerAgentProxyHandlerOverridableOptions): any;
    protected toPromise(resolve: (value: any) => any, reject: (reason: any) => any): Promise<any>;
    toJSON(): StackValue;
    toProxy(): any;
    get(target: any, p: string | symbol): any;
    set(target: any, p: string | symbol, newValue: any): boolean;
    deleteProperty(target: any, p: string | symbol): boolean;
    construct(target: any, argArray: any[]): object;
    apply(target: any, thisArg: any, argArray: any[]): any;
    getPrototypeOf(): object;
}
interface RefObject<T> {
    current: T;
}
export declare class CallerAgent {
    protected readonly targetKey: string;
    protected readonly broker: CallerBroker;
    protected readonly handler: CallerAgentProxyHandler;
    protected scope: CallerAgentScope;
    protected scopeRef: RefObject<CallerAgentScope>;
    constructor(options: CallerAgent.Options);
    getProxiedTarget(): any;
    getHelpers(): CallerAgent.Helpers;
    resolve(ret?: any): Promise<any>;
}
export declare namespace CallerAgent {
    interface Options {
        targetKey: string;
        broker: CallerBroker;
    }
    interface Helpers extends VariableHelper, CompareHelper, ValueCheckHelper, LogicFlowHelper {
        Math: MathHelper;
    }
}
export {};
