import { IAdapter } from '../adapters';
export declare abstract class Broker {
    protected readonly adapter: IAdapter;
    constructor(adapter: IAdapter);
    /**
     * On receive message from adapter
     * @param msg Adapter message
     */
    protected abstract onAdapterMessage(msg: unknown): void;
    /**
     * Dispose resources
     */
    dispose(): void;
}
export interface BrokerMessage {
    /**
     * Message unique type
     */
    readonly type: string;
    /**
     * Message payload
     */
    readonly payload?: any;
}
export interface BrokerRequest extends BrokerMessage {
    /**
     * Message session ID
     */
    readonly id: string;
}
export interface BrokerResponse {
    /**
     * Message session ID
     */
    readonly id: string;
    /**
     * Error
     */
    readonly error?: any;
    /**
     * Response payload
     */
    readonly payload?: any;
}
export declare function isResponse(msg: unknown): msg is BrokerResponse;
export declare function isEvent(msg: unknown): msg is BrokerMessage;
export declare function isRequest(msg: unknown): msg is BrokerRequest;
